@@ -35,10 +35,9 @@ def test_get_proj_str(test_output_path):
     assert p1 == p2
 
 
-
-    
 @pytest.mark.parametrize('crs', (True, False))
-@pytest.mark.parametrize('input', [(177955.0, 939285.0, 'epsg:5070', 'epsg:4269'),
+@pytest.mark.parametrize('input', [(554220.0, 391780.0, 3070, 3071),
+                                   (177955.0, 939285.0, 'epsg:5070', 'epsg:4269'),
                                    (-91.87370, 34.93738, 'epsg:4269', 'epsg:5070'),
                                    (-94.16583369760917, 31.142591218327198, 4269, 4326)
                                    ]
